@@ -786,6 +786,13 @@ class Sf:
         # Filter out Deprecated Profiles
         account_page_layouts_bulk = account_page_layouts_bulk[(~account_page_layouts_bulk['ProfileName'].isnull()) & (account_page_layouts_bulk['ProfileName'] != '') & (account_page_layouts_bulk['PageLayout'] != 'Veeva Vpro Unit Testing Layout')].copy()
         
+        if self.instance.__contains__("my.salesforce.com"):
+            sf_meta_instance = self.instance.replace("my.salesforce.com","")
+        else:
+            sf_meta_instance = ".".join(self.instance.split(".")[:1])
+        
+        account_page_layouts_bulk['Edit Link'] = account_page_layouts_bulk.apply(lambda row: "https://" + sf_meta_instance + ".lightning.force.com/lightning/setup/ObjectManager/" + row['DeveloperName'] + "/PageLayouts/" + row['ProfileLayout.LayoutId'], axis=1)
+        
         if return_pivot_table:
             return account_page_layouts_bulk.pivot(index='ProfileName', columns=['DeveloperName','RecordTypeName'], values='PageLayout')
         else:
